#!/usr/bin/perl
use strict;

my $IDtresh = 40;
my $Ltresh = 0.90;

my $usage = "
********************************************************************
* usage: vRTtoCLASS1 infile RTcore.fasta tableSequence.txt outfile *
*                                                                  *
* it classifies a query protein as far as its identity to some     *
* protein in the basa1 database is >= than the $IDtresh treshold.  *
* tableSequence.txt: name clade length                             *
********************************************************************
"; 

#$ENV{BLASTDIR} = '/usr/local/ncbi-blast';
#$ENV{BLASTMAT} = '/usr/local/ncbi-blast/data';

if ($#ARGV < 3)
{
    die "Incorrect argument number.\n$usage";
}
my $query = $ARGV[0];
my $basa = $ARGV[1];
my $basa2 = $ARGV[2];
my $outf = $ARGV[3];
my $repertoire = $ARGV[4];


my %basahash;

#Defining a hashes database
open (F0, "$basa2");
while (my $A1 = <F0>)
{
	chomp($A1);
	my ($family_name,$clade,$length) = split(' ', $A1);
	$basahash{$family_name} = { family_name => $family_name, clade => $clade, length => $length };
}
close (F0);


my $CMD = "cd $repertoire && formatdb -i $basa && blastall -p blastp -d $basa -i $query -F F -m 8 > dechet";
system($CMD);


my $ind = 0;
open (F3, ">$outf");
open (F1, "$repertoire/dechet");
while (my $L1 = <F1>)
{
	chomp($L1);
	my @X1 = split(' ', $L1);
	my $cover = $X1[9] - $X1[8] + 1;
	$ind = 0;
	if($X1[2] >= $IDtresh)
	{
    		my $N1 = $basahash{$X1[1]}->{family_name};
    		my $CL = $basahash{$X1[1]}->{clade};
    		my $LX = $basahash{$X1[1]}->{length};

    		my $ratio = $cover/$LX;
    		if ($ratio >= $Ltresh)
		{
			print F3 ($CL,"   Closest_family = ",$N1,"   Ident = ",$X1[2],"   Ratio = ",$ratio,"\n");
			$ind = 1;
			last;
    		} 
	}
}
if ($ind == 0)
{
	print F3 ("Ambiguous\n")
};
close (F1);
close (F3);


unlink("$repertoire/dechet");
unlink("formatdb.log");

